function [xt,Rx,yp]=Kalman(xt,yt,ut,M,N,A,B,Rw,Rv,Rx)
  // [xt,xf,Rx,yp]=Kalman(xt,yt,ut,M,N,A,B,Rw,Rv,Rx)
  // Kalman filter for state estimtion with the model
  //                             xt = M*xt + N*ut + w
  //                             yp = A*xt + B*ut + e
  // xt    state
  // Rx    state estimate covariance matrix
  // yp    output prediction
  // yt    output
  // ut    input
  // M,N   state model parameters
  // A,B   output model parameters
  // Rw    state model covariance
  // Rv    output model covariance

  // prediction
  xt=M*xt+N*ut;                        // time update of the state
  Rx=Rw+M*Rx*M';                       // time updt. of state covariance

  // filtration
  yp=A*xt+B*ut;                        // output prediction
  Ry=Rv+A*Rx*A';                       // noise covariance update
  Rx=Rx-Rx*A'*inv(Ry)*A*Rx;            // state est. covariance update
  ey=yt-yp;                            // prediction error 
  KG=Rx*A'*inv(Rv);                    // Kalman gain
  xt=xt+KG*ey;                         // data update of the state
endfunction
